@@ -127,15 +127,23 @@ impl Log for XLog {
                     Level::Warn => "color: white; background: #e17400",
                     Level::Error => "color: white; background: #b90008",
                 };
-                let msg_pre = match record.level() {
-                    Level::Trace => "color: #inherit",
-                    Level::Debug => "color: #inherit",
-                    Level::Info => "color: #inherit",
-                    Level::Warn => "color: #e17400",
-                    Level::Error => "color: #b90008",
+                let console_log = match record.level() {
+                    Level::Trace => console::debug_4,
+                    Level::Debug => console::log_4,
+                    Level::Info => console::info_4,
+                    Level::Warn => console::warn_4,
+                    Level::Error => console::error_4,
                 };
-                // let msg_pre = "color: inherit";
-                console::log_4(
+                // let msg_pre = match record.level() {
+                //     Level::Trace => "color: #inherit",
+                //     Level::Debug => "color: #inherit",
+                //     Level::Info => "color: #inherit",
+                //     Level::Warn => "color: #e17400",
+                //     Level::Error => "color: #b90008",
+                // };
+                let msg_pre = "color: inherit";
+
+                console_log(
                     &JsValue::from(format!("%c{}%c {} %c{}",
                                            level, pathname, msg
                     )),
